-- Set up our globals
global defkill

-- Reopen main window when user switches to EPPPD.
on activated theObject
	set visible of window "main" to true
end activated

on opened theObject
	-- First off, populate our baud rates list(because I'm too much of a fool to figure it out
	-- in the Interface Editor
	set rates to {"115200", "57600", "38400", "19200", "9600", "4800", "2400"}
	tell menu of popup button "bps" of window "main"
		delete every menu item
		repeat with irate in rates -- irate! get it?
			make new menu item at end of menu items with properties {title:irate}
		end repeat
	end tell
	
	-- Read in our Info.plist configurations
	set config to ((path to me as string) & "Contents:Info.plist")
	
	tell application "System Events"
		set defdev to value of property list item "DefaultDevice" of contents of property list file config
		set defbaud to value of property list item "DefaultBaudrate" of contents of property list file config
		set defip to value of property list item "DefaultTargetIP" of contents of property list file config
		set defdns to value of property list item "DefaultDNS" of contents of property list file config
		set defkill to value of property list item "DefaultKill" of contents of property list file config
	end tell
	
	-- Toggle our "kill on exit" button accordingly
	if defkill is true then
		set contents of button "keel" of window "main" to 1
	end if
	
	-- Set default baud
	if defbaud is not "" then
		set title of popup button "bps" of window "main" to defbaud
	end if
	-- Stuff to help parsing shell output
	set tid to AppleScript's text item delimiters
	set AppleScript's text item delimiters to return
	
	if defdev is "" then
		-- Get list of tty.* devices - prefer the default Bluetooth-PDA-Sync device, otherwise pick device
		-- from our list
		set devlist to do shell script "ls /dev/tty.*"
		if devlist contains "/dev/tty.Bluetooth-PDA-Sync" then
			set contents of text field "device" of window "main" to "/dev/tty.Bluetooth-PDA-Sync"
		else
			set contents of text field "device" of window "main" to text item 1 of devlist
		end if
	else
		set contents of text field "device" of window "main" to defdev
	end if
	
	-- The following is an excessive amount of "code" to get the second ip of the machine(first is generally 127.0.0.1)
	-- and assign it to the Target IP textbox
	if defip is "" then
		set networks to do shell script "ifconfig | sed -e 's/inet6//g'| grep inet | awk '{print $2}' | cut -d.  -f1-3"
		set probablenetwork to text item 2 of networks
		set contents of text field "targetip" of window "main" to text item 2 of networks & ".5"
	else
		set contents of text field "targetip" of window "main" to defip
	end if
	
	-- Get the first DNS in /etc/resolv.conf and assign it to the DNS textbox
	if defdns is "" then
		set dnslist to do shell script "cat /etc/resolv.conf | awk '{print $2}'"
		set contents of text field "DNS" of window "main" to text item 1 of dnslist
	else
		set contents of text field "DNS" of window "main" to defdns
	end if
	
	-- Set the parsing bits back to default(to be courteous to other scripts)
	set AppleScript's text item delimiters to tid
	
	-- Toggle our IP Forwarding checkbox according to sysctl settings:
	set ipforwarding to do shell script "sysctl net.inet.ip.forwarding | sed -e 's/net.inet.ip.forwarding: //g'"
	if ipforwarding is "0" then
		set contents of button "ipf" of window "main" to 0
	else
		set contents of button "ipf" of window "main" to 1
	end if
	
	-- Check to see if pppd is running, and based on that information, change the PID box and buttons
	set running to do shell script "ps -acx | grep pppd | awk '{print $1}'; exit 0"
	if running is "" then
		set title of button "execute" of window "main" of me to "Start"
	else
		set contents of text field "pid" of window "main" to running
		set title of button "execute" of window "main" of me to "Stop"
	end if
end opened

-- On button click stuff
-- Uses the follow order of ifs: exit, check, pid, log, execute, ipf

on clicked theObject
	if name of theObject is "exit" then
		if defkill is true then
			set running to do shell script "ps -acx | grep pppd; exit 0"
			if running is not "" then
				try
					do shell script "kill $(ps -acx | grep pppd | awk '{print $1}')" with administrator privileges
				end try
			end if
		end if
		tell me to quit
		
		-- check to see if pppd is running, then change PID text and buttons accordingly
	else if name of theObject is "check" then
		set running to do shell script "ps -acx | grep pppd | awk '{print $1}'; exit 0"
		if running is "" then
			set title of button "execute" of window "main" of me to "Start"
		else
			set title of button "execute" of window "main" of me to "Stop"
		end if
		set contents of text field "pid" of window "main" to running
		
		-- clear our log
	else if name of theObject is "clear" then
		do shell script "echo '' > /var/log/ppp.log" with administrator privileges
		
		-- Start up Console.app with /var/log/ppp.log
	else if name of theObject is "log" then
		-- this doesn't work on 10.5 x86, apparently?
		--	tell application "System Events" to open file ":var:log:ppp.log"
		
		tell application "Console"
			activate
			-- Gets our main boot drive(where /var/log/ppp.log should be)
			open (do shell script "ls -F /Volumes | sed -n 's/@$//p'") & ":var:log:ppp.log"
		end tell
		
		-- Parse UI input, then execute or kill pppd accordingly.
	else if name of theObject is "execute" then
		set device_ to contents of text field "device" of window "main" of me
		set targetip_ to contents of text field "targetip" of window "main" of me
		set DNS_ to contents of text field "DNS" of window "main" of me
		set bps_ to title of popup button "bps" of window "main" of me
		
		set running to do shell script "ps -acx | grep pppd | awk '{print $1}'; exit 0"
		if running is "" then
			do shell script "echo 'Starting: /usr/sbin/pppd " & device_ & " " & bps_ & " :" & targetip_ & " noauth local ms-dns " & DNS_ & " passive proxyarp asyncmap 0 silent logfile /var/log/ppp.log' >> /var/log/ppp.log" with administrator privileges
			do shell script "/usr/sbin/pppd " & device_ & " " & bps_ & "  :" & targetip_ & " noauth local ms-dns " & DNS_ & " passive proxyarp silent logfile /var/log/ppp.log" with administrator privileges
		else
			do shell script "kill $(ps -acx | grep pppd | awk '{print $1}')" with administrator privileges
		end if
		-- I hate delays, but a quick fix for ps -acx misreports
		delay 0.5
		set running to do shell script "ps -acx | grep pppd | awk '{print $1}'; exit 0"
		if running is "" then
			set title of button "execute" of window "main" of me to "Start"
		else
			set title of button "execute" of window "main" of me to "Stop"
		end if
		set contents of text field "pid" of window "main" to running
		
		-- Set IP forwarding based on the checkbox and current system settings.
	else if name of theObject is "ipf" then
		set ipf_ to contents of button "ipf" of window "main" of me
		set ipforwarding to do shell script "sysctl net.inet.ip.forwarding | sed -e 's/net.inet.ip.forwarding: //g'"
		if ipf_ is true and ipforwarding is "0" then
			do shell script "echo 'net.inet.ip.forwarding=1'>> /var/log/ppp.log" with administrator privileges
			do shell script "sysctl -w net.inet.ip.forwarding=1" with administrator privileges
		else if ipf_ is false and ipforwarding is "1" then
			do shell script "echo 'net.inet.ip.forwarding=0'>> /var/log/ppp.log" with administrator privileges
			do shell script "sysctl -w net.inet.ip.forwarding=0" with administrator privileges
		end if
		
		-- Save the settings for Device, Baud rate, Target IP, and DNS to EPPPD's internal Info.plist file
	else if name of theObject is "save" then
		set config to ((path to me as string) & "Contents:Info.plist")
		set device_ to contents of text field "device" of window "main" of me
		set targetip_ to contents of text field "targetip" of window "main" of me
		set DNS_ to contents of text field "DNS" of window "main" of me
		set bps_ to title of popup button "bps" of window "main" of me
		set kill_ to contents of button "keel" of window "main" of me
		
		tell application "System Events"
			set value of property list item "DefaultDevice" of contents of property list file config to device_
			set value of property list item "DefaultBaudrate" of contents of property list file config to bps_
			set value of property list item "DefaultTargetIP" of contents of property list file config to targetip_
			set value of property list item "DefaultDNS" of contents of property list file config to DNS_
			set value of property list item "DefaultKill" of contents of property list file config to kill_
		end tell
		
		-- Clear editable options
	else if name of theObject is "clearr" then
		set contents of text field "device" of window "main" to ""
		set contents of text field "targetip" of window "main" to ""
		set contents of text field "DNS" of window "main" to ""
		set contents of button "keel" of window "main" to ""
		set contents of popup button "bps" of window "main" to ""
		
		-- Display the Informations dialog if the "?" button is clicked
	else if name of theObject is "halp" then
		set visible of window "herp" to true
	else if name of theObject is "keel" then
		set defkill to contents of button "keel" of window "main"
	end if
end clicked

-- Menu stuff
on choose menu item theMenuItem
	-- Code to see if the pppd process should be killed on menu quit
	if title of theMenuItem is "Quit Excellent PPPD" then
		if defkill is true then
			set running to do shell script "ps -acx | grep pppd; exit 0"
			if running is not "" then
				try
					do shell script "kill $(ps -acx | grep pppd | awk '{print $1}')" with administrator privileges
				end try
			end if
		end if
		continue quit
		-- If Help menu item is selected, show Information panel
	else if title of theMenuItem is "Excellent PPPD Help" then
		set visible of window "herp" to true
	else if title of theMenuItem is "EPPPD" then
		set visible of window "main" to true
	end if
end choose menu item